
nocaselist - A case-insensitive list for Python
***********************************************

The project web site is: https://github.com/pywbem/nocaselist

.. toctree::
   :maxdepth: 2
   :numbered:

   intro.rst
   reference.rst
   development.rst
   appendix.rst
   changes.rst
